@@ -67,7 +67,7 @@ mainMenu.default <- function(e){
                   "installing courses yourself.",
                   "(If you are not connected to the internet, type 0 to exit.)")
         choices <- c(choices, "Don't install anything for me. I'll do it myself.")
-        choice <- select.list(choices)
+        choice <- select.list(choices, graphics=FALSE)
         n <- which(choice == choices)
         if(length(n) == 0)return(FALSE)
         if(n < length(choices)){
@@ -138,13 +138,14 @@ mainMenu.default <- function(e){
         # reverse path cosmetics
         lesson <- ifelse(lesson_choice=="", "",
                          lessons[lesson_choice == lessons_clean])
-        # Load the lesson and intialize everything
-        e$les <- loadLesson(e, courseU, lesson)
         # Return to the course menu if the lesson failed to load
-        if(is.logical(e$les) && !isTRUE(e$les)){
+        if(lesson == ""){
           rm("les", envir=e, inherits=FALSE)
           lesson <- ""
           next()
+        } else {
+          # Load the lesson and intialize everything
+          e$les <- loadLesson(e, courseU, lesson)
         }
       }
    # Remove temp lesson name and course name vars, which were surrogates
